reformat: This function changes the format of the longitudinal data...

View source: R/reformat.R

reformatR Documentation

This function changes the format of the longitudinal data from wide format to long format

Description

This function changes the format of the longitudinal data from wide format to long format

Usage

reformat(k,data,type="r")

Arguments

k

the number of repeated measurement.

data

either the response matrix or the predictor matrix.

type

"r" for response matrix, "d" for design matrix.

Value

the reformatted response vector or predictor matrix.


mixedBayes documentation built on March 17, 2026, 1:07 a.m.