reformat: This function changes the format of the longitudinal data from wide format to long format
Description
This function changes the format of the longitudinal data from wide format to long format
Usage
reformat(k,data,type=c("r","d"))Value
the reformatted response vector or predictor matrix.
Arguments
- k
the number of repeated measurement.
- data
either the response matrix or the predictor matrix.
- type
"r" for response, "d" for design.